@@ -38,8 +38,10 @@ NotepadPart::NotepadPart(QWidget *parentWidget, QObject *parent, const KPluginMe
 
     setReadWrite(true);
 
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 90)
     // Always write this as the last line of your constructor
     loadPlugins();
+#endif
 }
 
 NotepadPart::~NotepadPart()
@@ -65,7 +67,10 @@ bool NotepadPart::openFile()
     QString s;
     if (f.open(QIODevice::ReadOnly)) {
         QTextStream t(&f);
+        // The default with Qt6 is UTF-8
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         t.setCodec("UTF-8");
+#endif
         s = t.readAll();
         f.close();
     }
@@ -84,7 +89,9 @@ bool NotepadPart::saveFile()
     QFile f(localFilePath());
     if (f.open(QIODevice::WriteOnly)) {
         QTextStream t(&f);
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         t.setCodec("UTF-8");
+#endif
         t << m_edit->toPlainText();
         f.close();
         return true;
