@@ -9,15 +9,16 @@
 #ifndef __kparts_openurlevent_h__
 #define __kparts_openurlevent_h__
 
+#include <kparts/browserarguments.h>
 #include <kparts/event.h>
 #include <kparts/openurlarguments.h>
-#include <kparts/browserarguments.h>
 
 class QUrl;
 
 namespace KParts
 {
 class ReadOnlyPart;
+class OpenUrlEventPrivate;
 
 /**
  * @class OpenUrlEvent openurlevent.h <KParts/OpenUrlEvent>
@@ -31,10 +32,11 @@ class ReadOnlyPart;
 class KPARTS_EXPORT OpenUrlEvent : public Event
 {
 public:
-    OpenUrlEvent(ReadOnlyPart *part, const QUrl &url,
+    OpenUrlEvent(ReadOnlyPart *part,
+                 const QUrl &url,
                  const OpenUrlArguments &args = OpenUrlArguments(),
                  const BrowserArguments &browserArgs = BrowserArguments());
-    virtual ~OpenUrlEvent();
+    ~OpenUrlEvent() override;
 
     ReadOnlyPart *part() const;
     QUrl url() const;
@@ -44,8 +46,11 @@ public:
     static bool test(const QEvent *event);
 
 private:
-    class OpenUrlEventPrivate;
-    OpenUrlEventPrivate *const d;
+    Q_DECLARE_PRIVATE_D(Event::d, OpenUrlEvent)
+#if KPARTS_BUILD_DEPRECATED_SINCE(5, 79)
+    // Unused, kept for ABI compatibility
+    const void *__kparts_d_do_not_use;
+#endif
 };
 
 }
